@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # dbg-processor.sh - Bourne Again Shell Debugger Top-level debugger commands
 #
-#   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+#   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
 #   Rocky Bernstein rocky@gnu.org
 #
 #   bashdb is free software; you can redistribute it and/or modify it under
@@ -29,7 +29,6 @@
 #                       safely used (as per the bash manual on redirection)
 # _Dbg-input_desc       is the current descriptor in use. "sourc"ing other
 #                       command files will increase this descriptor
-
 typeset -ir _Dbg_INPUT_START_DESC=4
 typeset -i  _Dbg_MAX_INPUT_DESC=9  # logfile can reduce this
 typeset -i  _Dbg_input_desc=_Dbg_INPUT_START_DESC-1 # will ++ before use
@@ -97,7 +96,7 @@ function _Dbg_process_commands {
     typeset _Dbg_less=''
     typeset result  # Used by copies to return a value.
     
-    if _Dbg_copies '>' $BASHDB_LEVEL ; then
+    if _Dbg_copies '>' $_Dbg_DEBUGGER_LEVEL ; then
 	_Dbg_greater=$result
 	_Dbg_less=${result//>/<}
     fi
@@ -305,7 +304,7 @@ _Dbg_onecmd() {
 	  _Dbg_last_cmd='continue'
 	  if _Dbg_do_continue $args ; then
 	    _Dbg_write_journal_eval \
-	      "_Dbg_old_set_opts=\"$_Dbg_old_set_opts -o functrace\""
+	      "_Dbg_old_set_opts='$_Dbg_old_set_opts -o functrace'"
 	    return 0
 	  fi
 	  ;;
@@ -680,7 +679,7 @@ _Dbg_onecmd() {
 	   if (( _Dbg_autoeval )) ; then
 	     _Dbg_do_eval $_Dbg_cmd $args
 	   else
-             _Dbg_msg "Undefined command: \"$_Dbg_cmd\". Try \"help\"." 
+             _Dbg_undefined_cmd "$_Dbg_cmd"
 	     _Dbg_history_remove_item
 	     # local -a last_history=(`history 1`)
 	     # history -d ${last_history[0]}
