@@ -31,11 +31,11 @@ test_alias()
 }
 
 # Make sure ../.. has a trailing slash
-if [ '/src/external-cvs/bashdb-3.1' = '' ] ; then
+if [ '/src/external-vcs/bashdb' = '' ] ; then
   echo "Something is wrong: abs_top_srcdir is not set."
  exit 1
 fi
-abs_top_srcdir=/src/external-cvs/bashdb-3.1
+abs_top_srcdir=/src/external-vcs/bashdb
 abs_top_srcdir=${abs_top_srcdir%%/}/
 
 . $abs_top_srcdir/lib/help.sh
