@@ -17,18 +17,22 @@ test_preserve_set_opts()
 	# Name we refer to ourselves by
 	typeset _Dbg_debugger_name='bashdb'
 	# The release name we are configured to run under.
-	typeset _Dbg_release='4.0-0.2'
+	typeset _Dbg_release='4.0-0.4'
 	. ${top_builddir}/bashdb-trace -L $libdir
 	assertEquals $old_opts $-
     else
 	echo 'Skipping test - building outside of source complications'
     fi
+
+    (. ${top_builddir}/bashdb-trace -L $libdir/dbg-opts.sh)
+    assertEquals $? 1
+
 }
 
 # load shunit2
 prefix=/usr/local
-top_builddir=/src/external-cvs/bashdb-3.1
-top_srcdir=/src/external-cvs/bashdb-3.1
+top_builddir=/src/external-vcs/bashdb
+top_srcdir=/src/external-vcs/bashdb
 . ${top_srcdir}/lib/sig.sh
 . ${top_srcdir}/lib/help.sh
 . ${top_srcdir}/command/tracefn.sh
