@@ -39,11 +39,11 @@ test_columnized()
 
 }
 
-if [ '/src/external-cvs/bashdb-3.1' = '' ] ; then
+if [ '/src/external-vcs/bashdb' = '' ] ; then
   echo "Something is wrong abs_top_srcdir is not set."
  exit 1
 fi
-abs_top_srcdir=/src/external-cvs/bashdb-3.1
+abs_top_srcdir=/src/external-vcs/bashdb
 # Make sure @abs_top_srcr@ has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 
