@@ -23,12 +23,12 @@ test_do_show_version()
     # Name we refer to ourselves by
     typeset _Dbg_debugger_name='bashdb'
     # The release name we are configured to run under.
-    typeset _Dbg_release='4.0-0.2'
+    typeset _Dbg_release='4.0-0.4'
 
     version_string=$(_Dbg_do_show_version)
-    assertEquals "bashdb, release 4.0-0.2" "$version_string"
+    assertEquals "bashdb, release 4.0-0.4" "$version_string"
 }
-abs_top_srcdir=/src/external-cvs/bashdb-3.1
+abs_top_srcdir=/src/external-vcs/bashdb
 
 _Dbg_libdir=$abs_top_srcdir
 set -- -q  # Don't need to show banner
