@@ -19,7 +19,7 @@ test_save_restore_IFS_PS4()
     IFS="$old_IFS"
 }
 
-abs_top_srcdir=/src/external-cvs/bashdb-3.1
+abs_top_srcdir=/src/external-vcs/bashdb
 srcdir=.
 
 _Dbg_libdir=$abs_top_srcdir
